%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% OROS text-file analyzer

% This script is written for analyzing OROS.txt-files containing avgOct and 
% maxOct values in 1/3 octave bands from 20-20khz. Other values in the
% .txt-files will not be analyzable in this script without rewriting parts
% of it.

% Sort different measurefiles in their respective folders, and manage
% directory for matlab before running. Averaged values for all measurements
% in the directory-folder will be calculated and plotted, both max- and time
% -average.
% Plots are handled in an own script, as this script is purely calculations 
% to make variables. 'kjoring.m' needs to be run so the measurements
% from all folders are calculated and plotted.


% On behalf of Brekke&Strand, 
% Oskar Andreas Sivertsen, 2016

%% Creates a list of all textfiles in directory
result = {0};
fileList = 0;
[status, list] = system( 'dir /B *.txt' );
result = textscan( list, '%s', 'delimiter', '\t' );
fileList = result{1};


%% Creates a cell with all the documents, saves only the 2nd column.
%(measurement- values are located there)
doclist= {};
for i = 1:length(fileList);
    fileID = fopen(cell2mat(fileList(i,1)));
    doclist(i,1) = textscan(fileID,'%*s %s');% %*s ignores the first column
    fclose(fileID);
end



%% Finds the locations of 'Pa' in all the documents

name = 'Pa';
PaPos = {};
for i = 1:length(doclist)
    PaPos{i,1} = strfind(cellstr(doclist{i,1}),name);
end


%% Creates a matrix with the positions of 'Pa'. 

stringstart =[];
for i = 1:length(PaPos)
    for j = 1:length(PaPos{1,1})
        if PaPos{i,1}{j,1} ==1
            stringstart = [stringstart,j];
        end
    end
end
% Pa is located in same spot for all files.
stringstart = stringstart(1:(length(stringstart)/length(doclist)));


%% Adds only the measurementvalues into a new cell and converts to SPL
% (based on the position of 'Pa')

% Number of measurement values. 20-20kHz in 1/3 octave bands
measurelength=31; 

% Relative pressurelevel
p0=20*10^-6;

measurementsmatrix = zeros(measurelength,length(stringstart),length(doclist));

for i =1:length(doclist)
    for k = 1:length(stringstart)
        for j = 1:measurelength
            % Adds the measurementvalues from doclist into a new matrix
            % based on the positions of 'Pa' and converts to DOUBLE from 
            % string-values in the cell
            measurementsmatrix(j,k,i) = str2double(doclist{i,1}...
                 (stringstart(k)+j,1));
        end
    end
end

%% SPLmatrix / measurementsmatrix has a size: 31x12 x Ammount of documents.
% 31 different frequencies, 12 different mic values, where the 6 first are
% AvnOct and the 6 last are MaxOct. Ammount of documents varies for every
% runthrough of the different folders.
SPLmatrix = [0];
SPLmatrix = 20*log10(measurementsmatrix/p0);

%% Compensates for A-weighted measurement on mic 6
% This can be removed for other measurements.
% A-weighting values
 Aweight = [50.5,44.7,39.4,34.6,30.2,26.2,22.5,19.1,16.1,13.4,10.9,8.6,...
   6.6,4.8,3.2,1.9,0.8,0,-0.6,-1,-1.2,-1.3,-1.2,-1,-0.5,0.1,1.1,2.5,...
    4.3,6.6,9.3];

% for i =1:length(doclist)
%     for l = 1:2
%         SPLmatrix(:,l*6,i) = SPLmatrix(:,l*6,i) + Aweight.';
%     end
% end

%% Creating average values

% Reverts to P^2 - values for use in averaging
p2matrix = [0];
p2matrix = 10.^(SPLmatrix/10);

% Takes STD over all documents(per mic and freq)
p2std = 0;
xx = p2matrix(:,1:3,:);
yy = p2matrix(:,5:6,:);
p2std = std(xx,1,3);
p2std2 = std(yy,1,3);% 31x12
p2std = [p2std p2std2]; 
mean_std_p2 = 0;
mean_std_p2 = mean(p2std,2); % 31x1(averages std over mics)
Allmean_std_p2 = 0;
Allmean_std_p2 = mean(mean_std_p2); % Mean standard deviation

%Average over events
p2_averageacrossevent = 0;
p2_averageacrossevent = mean(p2matrix,3);
SPL_averageacrossevent = 0;
SPL_averageacrossevent = 10*log10(p2_averageacrossevent);
averagelist = SPL_averageacrossevent;

% Average over mics
p2_averageacrossmic_mean = 0;
p2_averageacrossmic_mean = mean(p2matrix(:,1:6,:),2);
SPL_averageacrossmic_mean = 0;
SPL_averageacrossmic_mean = 10*log10(p2_averageacrossmic_mean);
SPL_averageacrossmic_mean = squeeze(SPL_averageacrossmic_mean);

% Chosing of confidence-interval coefficient.
nobs = length(fileList)-1; %AKA DF
obs = length(fileList);

if nobs == 1;
    tp = 12.7;
elseif nobs == 2;
    tp = 4.3027;
elseif nobs == 3
    tp = 3.1824;
elseif nobs == 4
    tp = 2.7765;
elseif nobs == 5
    tp = 2.5706;
elseif nobs == 6
    tp = 2.4469;
elseif nobs == 7
    tp = 2.3646;
elseif  nobs == 8
    tp = 2.3060;
elseif nobs == 9
    tp = 2.2622;
elseif nobs == 10
    tp = 2.2281;
else
    tp = 2;
end

% Average over mic and freq
p2_averageacrossmicandfreq = [0];
p2_averageacrossmicandfreq = mean(p2_averageacrossmic_mean(:,:,1:size(fileList)),1);
p2_averageacrossmicandfreq = squeeze(p2_averageacrossmicandfreq);
SPL_averageacrossmicandfreq = 0;
SPL_averageacrossmicandfreq = 10*log10(p2_averageacrossmicandfreq);

% 95% konfidence interval
p2_mean = [0];
p2_mean = mean(p2_averageacrossmicandfreq);
p2_conf = 0;
p2_conf = (Allmean_std_p2/sqrt(obs))*tp;
SPL_conf = 10*log10(p2_conf);
SPL_mean = 0;
SPL_mean = 10*log10(p2_mean);
% Setting the upper and lower values for plotting konf.
Ubar = 10*log10(1 +(p2_conf/p2_mean));
Lbar = 10*log10(1 -(p2_conf/p2_mean));

std_micfreq = 0;
std_micfreq = std(p2_averageacrossmicandfreq);
std_micfreq = 10*log10(std_micfreq);


%Average over mics and events, mean
p2_averageacrosseventandmic_mean = 0;
p2_averageacrosseventandmic_mean = mean(p2_averageacrossevent(:,1:6),2);
SPL_averageacrosseventandmic_mean = 0;
SPL_averageacrosseventandmic_mean = 10*log10(p2_averageacrosseventandmic_mean);

%Converting to 1/1 octave for use in Odeon(source)(31.5Hz,63Hz,125Hz..)
SPLoctave = [0];
for i = 1:size(SPL_averageacrosseventandmic_mean)
    if mod(i,3) == 0
        SPLoctave(i/3) = 10*log10(10^(SPL_averageacrosseventandmic_mean...
            (i-1)/10) + 10^(SPL_averageacrosseventandmic_mean(i)/10) + ...
            10^(SPL_averageacrosseventandmic_mean(i+1)/10) );    
    end
end

%AweightingSPL
SPLA=0;
for i=1:size(Aweight)
   SPLA(i) =10^((SPL_averageacrosseventandmic_mean(i)-Aweight(i))/10); 
end
ASPL = 10*log10(sum(SPLA));

%Average over mics and events, max
p2_averageacrosseventandmic_max = 0;
p2_averageacrosseventandmic_max = mean(p2_averageacrossevent(:,7:12),2);
SPL_averageacrosseventandmic_max = 0;
SPL_averageacrosseventandmic_max = 10*log10(p2_averageacrosseventandmic_max);

%Average over mics and events, all
p2_averageacrosseventandmic_all = 0;
p2_averageacrosseventandmic_all = mean(p2_averageacrossevent(:,1:12),2);
SPL_averageacrosseventandmic_all = 0;
SPL_averageacrosseventandmic_all = 10*log10(p2_averageacrosseventandmic_all);

%Average over events and freq
p2_averageacrosseventandfreq = 0;
p2_averageacrosseventandfreq = mean(p2_averageacrossevent);
SPL_averageeventandfreq = 0;
SPL_averageeventandfreq = 10*log10(p2_averageacrosseventandfreq);

%Average over everything
SPL_p2_averageacrosseventandmicanddoc = 0;
SPL_p2_averageacrosseventandmicanddoc = 10*log10(mean((p2_averageacrosseventandfreq)));

