%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Pick a directory to run from, and CD will load different folders and then
% run OROSplotting_PS222222 for the different folders 1 by 1. This will
% result in variables and averages for all the different measurementfiles
% to be saved in various matrixes for comparison.


% Oskar Andreas Sivertsen, 2016


%% Main file with all the measurementfiles for a total average
cd Trikkemaling
OROSplotting_PS222222
avgall = SPL_averageacrosseventandmic_mean;
maxall = SPL_averageacrosseventandmic_max;
SPL_all = SPL_mean;
mics_all = averagelist;
AverageAllEventFreq = SPL_averageeventandfreq;

MaxMic = AverageAllEventFreq(7:12);
AvgMic = AverageAllEventFreq(1:6);

%For setting the plots ranges
maxyval = max(max(averagelist));
maxyval = ceil(maxyval/5)*5;

%% Loading all the different folders and respective measurementfiles
% All different variables will be saved individually for different vehicles
% and their directions.
cd ('..')
cd Trikkemaling/Bussinn
OROSplotting_PS222222
SPL_bussinn = SPL_mean;
mics_bussinn = averagelist;
avg_Bussinn = SPL_averageacrosseventandmic_mean;
Ubussinn = Ubar;
Lbussinn = Lbar;
AvgMicBi = SPL_averageeventandfreq(1:6);
stdBussinn = Allmean_std_p2;

cd ../..
cd Trikkemaling/Bussut
OROSplotting_PS222222
SPL_bussut = SPL_mean;
Averageacrossevent_Bussut = SPL_averageacrossevent;
mics_bussut = averagelist;
avg_Bussut = SPL_averageacrosseventandmic_mean;
Ubussut = Ubar;
Lbussut = Lbar;
AvgMicBu = SPL_averageeventandfreq(1:6);
stdBussut = Allmean_std_p2;

cd ../..
cd Trikkemaling/SL79inn
OROSplotting_PS222222
SPL_SL79in = SPL_mean;
mics_SL79inn = averagelist;
avg_SL79inn = SPL_averageacrosseventandmic_mean;
USL79inn = Ubar;
LSL79inn = Lbar;
AvgMicSi = SPL_averageeventandfreq(1:6);
SPLoctSL79inn = SPLoctave(2:9);
stdSL79inn = Allmean_std_p2;

cd ../..
cd Trikkemaling/SL79ut
OROSplotting_PS222222
SPL_SL79ut = SPL_mean;
mics_SL79ut = averagelist;
avg_SL79ut = SPL_averageacrosseventandmic_mean;
USL79ut = Ubar;
LSL79ut = Lbar;
AvgMicSu = SPL_averageeventandfreq(1:6);
SPLoctSL79ut = SPLoctave(2:9);
stdSL79ut = Allmean_std_p2;


cd ../..
cd Trikkemaling/SL95inn
OROSplotting_PS222222
SPL_SL95in = SPL_mean;
mics_SL95inn = averagelist;
avg_SL95inn = SPL_averageacrosseventandmic_mean;
USL95inn = Ubar;
LSL95inn = Lbar;
AvgMicSsi = SPL_averageeventandfreq(1:6);
SPLoctSL95inn = SPLoctave(2:9); % For 1/1 oct 63-8kHz
stdSL95inn = Allmean_std_p2;

cd ../..
cd Trikkemaling/SL95ut
OROSplotting_PS222222
SPL_SL95ut = SPL_mean;
Averageacrossevent_SL95ut = SPL_averageacrossevent;
mics_SL95ut = averagelist;
avg_SL95ut = SPL_averageacrosseventandmic_mean;
USL95ut = Ubar;
LSL95ut = Lbar;
AvgMicSsu = SPL_averageeventandfreq(1:6);
SPLoctSL95ut = SPLoctave(2:9);
stdSL95ut = Allmean_std_p2;

% CD to get back to starting directory
cd ../..
%% Saving the individual variables into matrices to plot them together
% Average over event, mic and freq for the different vehicles
AvgVehicles = [SPL_bussinn,SPL_bussut,SPL_SL79in,SPL_SL79ut,SPL_SL95in,SPL_SL95ut];

% 95%confidence-interval
Uconf = [Ubussinn,Ubussut,USL79inn,USL79ut,USL95inn,USL95ut]; 
%Lconf = abs([Lbussinn,Lbussut,LSL79inn,LSL79ut,LSL95inn,LSL95ut]);
Lconf = abs([-470,-24,LSL79inn,LSL79ut,LSL95inn,LSL95ut]);

%Average over event and mic for the different vehicles
AvgVehicdir = [avg_Bussinn,avg_Bussut,avg_SL79inn,avg_SL79ut,avg_SL95inn,avg_SL95ut];

% Std for different vehicles
stdALL = [stdBussinn,stdBussut,stdSL79inn,stdSL79ut,stdSL95inn,stdSL95ut];

%% Plotting
% Below is a long list of different plots for all measurementvalues for the
% 6 different vehicles/directions. Titles/comments will be explaining what
% the different plots are

% Frequency range: 20-20kHz in 1/3 octave bands
frequency_range=[2e+1,2.5e+1,3.15e+1,4e+1,5e+1,6.3e+1,8e+1,1e+2,1.25e+2,...
    1.6e+2,2e+2,2.5e+2,3.15e+2,4e+2,5e+2,6.3e+2,8e+2,1e+3,1.25e+3,1.6e+3,...
    2e+3,2.5e+3,3.15e+3,4e+3,5e+3,6.3e+3,8e+3,1e+4,1.25e+4,1.6e+4,2e+4];

color = ['r','b','y','g','m','k'];

iv = [1:length(frequency_range)];

% Naming the x-axis values
labelvec{1} = '31.5';
labelvec{2} = '63';
labelvec{3} = '125';
labelvec{4} = '250';
labelvec{5} = '500';
labelvec{6} = '1k';
labelvec{7} = '2k';
labelvec{8} = '4k';
labelvec{9} = '8k';
labelvec{10} = '16k';
%% Buss inn
figure(1)
h1 = plot(iv,mics_bussinn(:,1:3));
hold on
plot(iv,mics_bussinn(:,5:6));
h1diagram = get(h1(1),'Parent');
set(h1diagram,'XTick',[3 6 9 12 15 18 21 24 27 30]);
set(h1diagram,'XTickLabel',labelvec)
set(h1diagram,'FontSize',14);
ylim([maxyval-50 maxyval-5])
grid
g = xlabel('Frequency [Hz] 1/3 octave bands');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('Bus in noise measurements avg');
set(g,'FontSize',14);
g = legend('4.9m,','4.4m','3.6m','2.4m','1.75m');

figure(2)
h2 = plot(iv,mics_bussinn(:,7:9));
hold on
plot(iv,mics_bussinn(:,11:12));
h2diagram = get(h2(1),'Parent');
set(h2diagram,'XTick',[3 6 9 12 15 18 21 24 27 30]);
set(h2diagram,'XTickLabel',labelvec)
set(h2diagram,'FontSize',14);
ylim([maxyval-40 maxyval+7])
grid
g = xlabel('Frequency [Hz] 1/3 octave bands');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('Bus in noise measurement max');
set(g,'FontSize',14);
g = legend('4.9m,','4.4m','3.6m','2.4m','1.75m');

%% Buss ut
figure(3)
h1 = plot(iv,mics_bussut(:,1:3));
hold on
plot(iv,mics_bussut(:,5:6));
h1diagram = get(h1(1),'Parent');
set(h1diagram,'XTick',[3 6 9 12 15 18 21 24 27 30]);
set(h1diagram,'XTickLabel',labelvec)
set(h1diagram,'FontSize',14);
ylim([maxyval-50 maxyval+10])
grid
g = xlabel('Frequency [Hz] 1/3 octave bands');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('Bus out noise measurements avg');
set(g,'FontSize',14);
g = legend('4.9m,','4.4m','3.6m','2.4m','1.75m');

figure(4)
h2 = plot(iv,mics_bussut(:,7:9));
hold on
plot(iv,mics_bussut(:,11:12));
h2diagram = get(h2(1),'Parent');
set(h2diagram,'XTick',[3 6 9 12 15 18 21 24 27 30]);
set(h2diagram,'XTickLabel',labelvec)
set(h2diagram,'FontSize',14);
ylim([maxyval-40 maxyval+10])
grid
g = xlabel('Frequency [Hz] 1/3 octave bands');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('Bus out noise measurement max');
set(g,'FontSize',14);
g = legend('4.9m,','4.4m','3.6m','2.4m','1.75m');

%% SL79 inn
figure(5)
h1 = plot(iv,mics_SL79inn(:,1:3));
hold on
plot(iv,mics_SL79inn(:,5:6));
h1diagram = get(h1(1),'Parent');
set(h1diagram,'XTick',[3 6 9 12 15 18 21 24 27 30]);
set(h1diagram,'XTickLabel',labelvec)
set(h1diagram,'FontSize',14);
ylim([maxyval-50 maxyval-10])
grid
g = xlabel('Frequency [Hz] 1/3 octave bands');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('SL79 in noise measurements avg');
set(g,'FontSize',14);
g = legend('4.9m,','4.4m','3.6m','2.4m','1.75m');

figure(6)
h2 = plot(iv,mics_SL79inn(:,7:9));
hold on
plot(iv,mics_SL79inn(:,11:12));
h2diagram = get(h2(1),'Parent');
set(h2diagram,'XTick',[3 6 9 12 15 18 21 24 27 30]);
set(h2diagram,'XTickLabel',labelvec)
set(h2diagram,'FontSize',14);
ylim([maxyval-40 maxyval])
grid
g = xlabel('Frequency [Hz] 1/3 octave bands');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('SL79 in noise measurement max');
set(g,'FontSize',14);
g = legend('4.9m,','4.4m','3.6m','2.4m','1.75m');

%% SL79 ut
figure(7)
h1 = plot(iv,mics_SL79ut(:,1:3));
hold on
plot(iv,mics_SL79ut(:,5:6));
h1diagram = get(h1(1),'Parent');
set(h1diagram,'XTick',[3 6 9 12 15 18 21 24 27 30]);
set(h1diagram,'XTickLabel',labelvec)
set(h1diagram,'FontSize',14);
ylim([45 90])
grid
g = xlabel('Frequency [Hz] 1/3 octave bands');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('SL79 out noise measurements avg');
set(g,'FontSize',14);
g = legend('4.9m,','4.4m','3.6m','2.4m','1.75m');


figure(8)
h2 = plot(iv,mics_SL79ut(:,7:9));
hold on
plot(iv,mics_SL79ut(:,11:12));
h2diagram = get(h2(1),'Parent');
set(h2diagram,'XTick',[3 6 9 12 15 18 21 24 27 30]);
set(h2diagram,'XTickLabel',labelvec)
set(h2diagram,'FontSize',14);
ylim([maxyval-40 maxyval])
grid
g = xlabel('Frequency [Hz] 1/3 octave bands');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('SL79 out noise measurement max');
set(g,'FontSize',14);
g = legend('4.9m,','4.4m','3.6m','2.4m','1.75m');

%% SL95 inn
figure(9)
h1 = plot(iv,mics_SL95inn(:,1:3));
hold on
plot(iv,mics_SL95inn(:,5:6));
h1diagram = get(h1(1),'Parent');
set(h1diagram,'XTick',[3 6 9 12 15 18 21 24 27 30]);
set(h1diagram,'XTickLabel',labelvec)
set(h1diagram,'FontSize',14);
ylim([45 90])
grid
g = xlabel('Frequency [Hz] 1/3 octave bands');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('SL95 in noise measurements avg');
set(g,'FontSize',14);
g = legend('4.9m,','4.4m','3.6m','2.4m','1.75m');


figure(10)
h2 = plot(iv,mics_SL95inn(:,7:9));
hold on
plot(iv,mics_SL95inn(:,11:12));
h2diagram = get(h2(1),'Parent');
set(h2diagram,'XTick',[3 6 9 12 15 18 21 24 27 30]);
set(h2diagram,'XTickLabel',labelvec)
set(h2diagram,'FontSize',14);
ylim([45 90])
grid
g = xlabel('Frequency [Hz] 1/3 octave bands');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('SL95 in noise measurement max');
set(g,'FontSize',14);
g = legend('4.9m,','4.4m','3.6m','2.4m','1.75m');

%% SL95 ut
figure(11)
h1 = plot(iv,mics_SL95ut(:,1:3));
hold on
plot(iv,mics_SL95ut(:,5:6));
h1diagram = get(h1(1),'Parent');
set(h1diagram,'XTick',[3 6 9 12 15 18 21 24 27 30]);
set(h1diagram,'XTickLabel',labelvec)
set(h1diagram,'FontSize',14);
ylim([maxyval-50 maxyval-6])
grid
g = xlabel('Frequency [Hz] 1/3 octave bands');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('SL95 out noise measurements avg');
set(g,'FontSize',14);
g = legend('4.9m,','4.4m','3.6m','2.4m','1.75m');

figure(12)
h2 = plot(iv,mics_SL95ut(:,7:9));
hold on
plot(iv,mics_SL95ut(:,11:12));
h2diagram = get(h2(1),'Parent');
set(h2diagram,'XTick',[3 6 9 12 15 18 21 24 27 30]);
set(h2diagram,'XTickLabel',labelvec)
set(h2diagram,'FontSize',14);
ylim([maxyval-40 maxyval+3])
grid
g = xlabel('Frequency [Hz] 1/3 octave bands');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('SL95 out noise measurement max');
set(g,'FontSize',14);
g = legend('4.9m,','4.4m','3.6m','2.4m','1.75m');


%% Average over vehicles

figure(13)
inaverages = AvgVehicles;
trainbar{1} = 'Bus in';
trainbar{2} = 'Bus out';
trainbar{3} = 'SL79 in';
trainbar{4} = 'SL79 out';
trainbar{5} = 'SL95 in';
trainbar{6} = 'SL95 out';
h1 = bar(inaverages);
h1diagram = get(h1(1),'Parent');
set(h1diagram,'XTick',[1 2 3 4 5 6]);
set(h1diagram,'XTickLabel',trainbar)
set(h1diagram,'FontSize',10);
grid
ylim([65 85])
g = xlabel('Vehicle type and direction');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('Average across vehicles ');
set(g,'FontSize',14);


%% Konfidensintervall
figure(14)
%trainbar{1} = 'Bus in';
%trainbar{2} = 'Bus out';
trainbar{1} = 'SL79 in';
trainbar{2} = 'SL79 out';
trainbar{3} = 'SL95 in';
trainbar{4} = 'SL95 out';
%h1 = errorbar(1:6,AvgVehicles,Lconf,Uconf,'X');
w1 = 0.5;
w2 = 0.5;
w3 = 0.5;
h1 = bar(3:6,AvgVehicles(3:6)+Uconf(3:6),w1,'FaceColor',[1 0 0]);
h1diagram = get(h1(1),'Parent');
set(h1diagram,'XTick',[3 4 5 6]);
set(h1diagram,'XTickLabel',trainbar)
set(h1diagram,'FontSize',10);
grid
ylim([55 80])
g = xlabel('Vehicle type and direction');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('Average across vehicles ');
set(g,'FontSize',14);
hold on
bar(3:6,AvgVehicles(3:6)+0.20,w2,'FaceColor',[0 1 0])
hold on
bar(3:6,AvgVehicles(3:6)-0.20,w2,'FaceColor',[1 0 0])
hold on
bar(3:6,AvgVehicles(3:6) - Lconf(3:6),w3,'FaceColor',[0 0 1])
legend('95% Confidence interval','Mean value');

%% All
figure(15)
h1 = plot(iv,maxall,iv,avgall);
h1diagram = get(h1(1),'Parent');
set(h1diagram,'XTick',[3 6 9 12 15 18 21 24 27 30]);
set(h1diagram,'XTickLabel',labelvec)
set(h1diagram,'FontSize',14);
ylim([maxyval-40 maxyval])
grid
g = xlabel('Frequency [Hz] 1/3 octave bands');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('Measurement avg over all microphones ');
set(g,'FontSize',14);
g = legend('max','mean');

figure(16)
h2 = plot(iv,mics_all(:,1:3));
hold on
plot(iv,mics_all(:,5:6));
h2diagram = get(h2(1),'Parent');
set(h2diagram,'XTick',[3 6 9 12 15 18 21 24 27 30]);
set(h2diagram,'XTickLabel',labelvec)
set(h2diagram,'FontSize',14);
ylim([60 95])
grid
g = xlabel('Frequency [Hz] 1/3 octave bands');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('Average of all measurements, vehicles and directions');
set(g,'FontSize',14);
g = legend('4.9m,','4.4m','3.6m','2.4m','1.75m');

%% Comparisons on directions per vehicle
figure(17)
h2 = plot(iv,AvgVehicdir(:,1:2));
h2diagram = get(h2(1),'Parent');
set(h2diagram,'XTick',[3 6 9 12 15 18 21 24 27 30]);
set(h2diagram,'XTickLabel',labelvec)
set(h2diagram,'FontSize',14);
ylim([maxyval-40 maxyval+2])
grid
g = xlabel('Frequency [Hz] 1/3 octave bands');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('Bus directions averaged over mics');
set(g,'FontSize',14);
g = legend('Bus in','Bus out');

figure(18)
h2 = plot(iv,AvgVehicdir(:,3:4));
h2diagram = get(h2(1),'Parent');
set(h2diagram,'XTick',[3 6 9 12 15 18 21 24 27 30]);
set(h2diagram,'XTickLabel',labelvec)
set(h2diagram,'FontSize',14);
ylim([50 85])
grid
g = xlabel('Frequency [Hz] 1/3 octave bands');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('SL79 directions averaged over mics');
set(g,'FontSize',14);
g = legend('SL79 in','SL79 out');

figure(19)
h2 = plot(iv,AvgVehicdir(:,5:6));
h2diagram = get(h2(1),'Parent');
set(h2diagram,'XTick',[3 6 9 12 15 18 21 24 27 30]);
set(h2diagram,'XTickLabel',labelvec)
set(h2diagram,'FontSize',14);
ylim([50 85])
grid
g = xlabel('Frequency [Hz] 1/3 octave bands');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('SL95 directions averaged over mics');
set(g,'FontSize',14);
g = legend('SL95 in','SL95 out');

figure(20)
h2 = plot(iv,AvgVehicdir(:,1),iv,AvgVehicdir(:,3),iv,AvgVehicdir(:,5));
h2diagram = get(h2(1),'Parent');
set(h2diagram,'XTick',[3 6 9 12 15 18 21 24 27 30]);
set(h2diagram,'XTickLabel',labelvec)
set(h2diagram,'FontSize',14);
ylim([maxyval-40 maxyval+2])
grid
g = xlabel('Frequency [Hz] 1/3 octave bands');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('Vehicles going in averaged over mics');
set(g,'FontSize',14);
g = legend('Buss inn','SL79 inn','SL95 inn');

figure(21)
h2 = plot(iv,AvgVehicdir(:,2),iv,AvgVehicdir(:,4),iv,AvgVehicdir(:,6));
h2diagram = get(h2(1),'Parent');
set(h2diagram,'XTick',[3 6 9 12 15 18 21 24 27 30]);
set(h2diagram,'XTickLabel',labelvec)
set(h2diagram,'FontSize',14);
ylim([maxyval-40 maxyval+2])
grid
g = xlabel('Frequency [Hz] 1/3 octave bands');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('Vehicles going out averaged over mics');
set(g,'FontSize',14);
g = legend('Buss ut','SL79 ut','SL95 ut');

figure(22)
h2 = plot(iv,AvgVehicdir);
h2diagram = get(h2(1),'Parent');
set(h2diagram,'XTick',[3 6 9 12 15 18 21 24 27 30]);
set(h2diagram,'XTickLabel',labelvec)
set(h2diagram,'FontSize',14);
ylim([maxyval-40 maxyval+2])
grid
g = xlabel('Frequency [Hz] 1/3 octave bands');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('Vehicles and their direction - averaged over mics');
set(g,'FontSize',14);
g = legend('Buss inn','Buss ut','SL79 inn','SL79 ut','SL95 inn','SL95 ut');

%% Plotting of Max and Avg mic-values averaged across event and freq.(BAR)
figure(23)
%Widths for barplot
w1= 0.5;
w2 = 0.25;
trainbar{1} = '4.90m';
trainbar{2} = '4.40m';
trainbar{3} = '3.60m';
trainbar{4} = '2.40m';
trainbar{5} = '1.75m';
h1 = bar(1:3,MaxMic(1:3),w1,'FaceColor',[0.2 0.2 0.5]);
hold on
bar(4:5,MaxMic(5:6),w1,'FaceColor',[0.2 0.2 0.5]);
h1diagram = get(h1(1),'Parent');
set(h1diagram,'XTick',[1 2 3 4 5]);
set(h1diagram,'XTickLabel',trainbar)
set(h1diagram,'FontSize',10);
grid
ylim([70 85])
g = xlabel('Microphones heights ');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('Maximum- and average values across microphones');
set(g,'FontSize',14);
hold on
h2 = bar(1:3,AvgMic(1:3),w2,'FaceColor',[1 0.1 0.1]);
bar(4:5,AvgMic(5:6),w2,'FaceColor',[1 0.1 0.1]);
legend([h1,h2],'Max-values','Time-averaged values','Location','northwest')


%% Mics over distance(All directions compared at same mic)
figure(24)
h2 = plot(iv,mics_bussinn(:,1),iv,mics_bussut(:,1),iv,mics_SL79inn(:,1),iv,mics_SL79ut(:,1),iv,mics_SL95inn(:,1),iv,mics_SL95ut(:,1));
h2diagram = get(h2(1),'Parent');
set(h2diagram,'XTick',[3 6 9 12 15 18 21 24 27 30]);
set(h2diagram,'XTickLabel',labelvec)
set(h2diagram,'FontSize',14);
ylim([maxyval-40 maxyval+2])
grid
g = xlabel('Frequency [Hz] 1/3 octave bands');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('Vehicles/direction at microphone at 4.9m');
set(g,'FontSize',14);
g = legend('Buss inn','Buss ut','SL79 inn','SL79 ut','SL95 inn','SL95 ut');

figure(25)
h2 = plot(iv,mics_bussinn(:,2),iv,mics_bussut(:,2),iv,mics_SL79inn(:,2),iv,mics_SL79ut(:,2),iv,mics_SL95inn(:,2),iv,mics_SL95ut(:,2));
h2diagram = get(h2(1),'Parent');
set(h2diagram,'XTick',[3 6 9 12 15 18 21 24 27 30]);
set(h2diagram,'XTickLabel',labelvec)
set(h2diagram,'FontSize',14);
ylim([maxyval-40 maxyval+2])
grid
g = xlabel('Frequency [Hz] 1/3 octave bands');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('Vehicles/direction at microphone at 4.4m');
set(g,'FontSize',14);
g = legend('Buss inn','Buss ut','SL79 inn','SL79 ut','SL95 inn','SL95 ut');

figure(26)
h2 = plot(iv,mics_bussinn(:,3),iv,mics_bussut(:,3),iv,mics_SL79inn(:,3),iv,mics_SL79ut(:,3),iv,mics_SL95inn(:,3),iv,mics_SL95ut(:,3));
h2diagram = get(h2(1),'Parent');
set(h2diagram,'XTick',[3 6 9 12 15 18 21 24 27 30]);
set(h2diagram,'XTickLabel',labelvec)
set(h2diagram,'FontSize',14);
ylim([maxyval-40 maxyval+2])
grid
g = xlabel('Frequency [Hz] 1/3 octave bands');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('Vehicles/direction at microphone at 3.6m');
set(g,'FontSize',14);
g = legend('Buss inn','Buss ut','SL79 inn','SL79 ut','SL95 inn','SL95 ut');

figure(27)
h2 = plot(iv,mics_bussinn(:,4),iv,mics_bussut(:,4),iv,mics_SL79inn(:,4),iv,mics_SL79ut(:,4),iv,mics_SL95inn(:,4),iv,mics_SL95ut(:,4));
h2diagram = get(h2(1),'Parent');
set(h2diagram,'XTick',[3 6 9 12 15 18 21 24 27 30]);
set(h2diagram,'XTickLabel',labelvec)
set(h2diagram,'FontSize',14);
ylim([maxyval-40 maxyval+2])
grid
g = xlabel('Frequency [Hz] 1/3 octave bands');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('Vehicles/direction at microphone at 3.1m');
set(g,'FontSize',14);
g = legend('Buss inn','Buss ut','SL79 inn','SL79 ut','SL95 inn','SL95 ut');

figure(28)
h2 = plot(iv,mics_bussinn(:,5),iv,mics_bussut(:,5),iv,mics_SL79inn(:,5),iv,mics_SL79ut(:,5),iv,mics_SL95inn(:,5),iv,mics_SL95ut(:,5));
h2diagram = get(h2(1),'Parent');
set(h2diagram,'XTick',[3 6 9 12 15 18 21 24 27 30]);
set(h2diagram,'XTickLabel',labelvec)
set(h2diagram,'FontSize',14);
ylim([maxyval-40 maxyval+2])
grid
g = xlabel('Frequency [Hz] 1/3 octave bands');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('Vehicles/direction at microphone at 2.4m');
set(g,'FontSize',14);
g = legend('Buss inn','Buss ut','SL79 inn','SL79 ut','SL95 inn','SL95 ut');

figure(29)
h2 = plot(iv,mics_bussinn(:,6),iv,mics_bussut(:,6),iv,mics_SL79inn(:,6),iv,mics_SL79ut(:,6),iv,mics_SL95inn(:,6),iv,mics_SL95ut(:,6));
h2diagram = get(h2(1),'Parent');
set(h2diagram,'XTick',[3 6 9 12 15 18 21 24 27 30]);
set(h2diagram,'XTickLabel',labelvec)
set(h2diagram,'FontSize',14);
ylim([maxyval-40 maxyval+2])
grid
g = xlabel('Frequency [Hz] 1/3 octave bands');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('Vehicles/direction at microphone at 1.75m');
set(g,'FontSize',14);
g = legend('Buss inn','Buss ut','SL79 inn','SL79 ut','SL95 inn','SL95 ut');

figure(30)
h2 = plot(iv,AvgVehicdir(:,3:6));
h2diagram = get(h2(1),'Parent');
set(h2diagram,'XTick',[3 6 9 12 15 18 21 24 27 30]);
set(h2diagram,'XTickLabel',labelvec)
set(h2diagram,'FontSize',14);
ylim([55 85])
grid
g = xlabel('Frequency [Hz] 1/3 octave bands');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('SL79 and SL95 directions averaged over mics');
set(g,'FontSize',14);
g = legend('SL79 in','SL79 out','SL95 inn','SL95 ut');

figure(31)
h2 = plot(iv,(AvgVehicdir(:,3)+AvgVehicdir(:,4))/2,iv,(AvgVehicdir(:,5)+AvgVehicdir(:,6))/2);
h2diagram = get(h2(1),'Parent');
set(h2diagram,'XTick',[3 6 9 12 15 18 21 24 27 30]);
set(h2diagram,'XTickLabel',labelvec)
set(h2diagram,'FontSize',14);
ylim([55 85])
grid
g = xlabel('Frequency [Hz] 1/3 octave bands');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('SL79 and SL95 directions averaged over mics and directions');
set(g,'FontSize',14);
g = legend('SL79','SL95');

figure(32)
%Widths for barplot
w1= 0.5;
w2 = 0.25;
trainbar{1} = '4.90m';
trainbar{2} = '4.40m';
trainbar{3} = '3.60m';
trainbar{4} = '2.40m';
trainbar{5} = '1.75m';
h1 = bar(1:3,AvgMicSsu(1:3),w1,'FaceColor',[0.2 0.2 0.5]);
h1diagram = get(h1(1),'Parent');
set(h1diagram,'XTick',[1 2 3 4 5]);
set(h1diagram,'XTickLabel',trainbar)
set(h1diagram,'FontSize',10);
grid
ylim([67 86])
g = xlabel('Microphone heights ');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('Average for mics, SL95');
set(g,'FontSize',14);
hold on
bar(4:5,AvgMicSsu(5:6),w1,'FaceColor',[0.2 0.2 0.5]);
h2 = bar(1:3,AvgMicSsi(1:3),w2,'FaceColor',[1 0.1 0.1]);
bar(4:5,AvgMicSsi(5:6),w2,'FaceColor',[1 0.1 0.1]);
legend([h1,h2],'Out','In','Location','northwest')

figure(33)
%Widths for barplot
w1= 0.5;
w2 = 0.25;
trainbar{1} = '4.90m';
trainbar{2} = '4.40m';
trainbar{3} = '3.60m';
trainbar{4} = '2.40m';
trainbar{5} = '1.75m';
h1 = bar(1:3,AvgMicSu(1:3),w1,'FaceColor',[0.2 0.2 0.5]);
h1diagram = get(h1(1),'Parent');
set(h1diagram,'XTick',[1 2 3 4 5]);
set(h1diagram,'XTickLabel',trainbar)
set(h1diagram,'FontSize',10);
grid
ylim([67 86])
g = xlabel('Microphone heights ');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('Average for mics, SL79');
set(g,'FontSize',14);
hold on
bar(4:5,AvgMicSu(5:6),w1,'FaceColor',[0.2 0.2 0.5]);
h2 = bar(1:3,AvgMicSi(1:3),w2,'FaceColor',[1 0.1 0.1]);
bar(4:5,AvgMicSi(5:6),w2,'FaceColor',[1 0.1 0.1]);
legend([h1,h2],'Out','In','Location','northwest')

figure(34)
%Widths for barplot
w1= 0.5;
w2 = 0.25;
trainbar{1} = '4.90m';
trainbar{2} = '4.40m';
trainbar{3} = '3.60m';
trainbar{4} = '2.40m';
trainbar{5} = '1.75m';
h1 = bar(1:3,AvgMicBu(1:3),w1,'FaceColor',[0.2 0.2 0.5]);
h1diagram = get(h1(1),'Parent');
set(h1diagram,'XTick',[1 2 3 4 5]);
set(h1diagram,'XTickLabel',trainbar)
set(h1diagram,'FontSize',10);
grid
ylim([67 86])
g = xlabel('Microphone heights ');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('Average for mics, Bus');
set(g,'FontSize',14);
hold on
bar(4:5,AvgMicBu(5:6),w1,'FaceColor',[0.2 0.2 0.5]);
h2 = bar(1:3,AvgMicBi(1:3),w2,'FaceColor',[1 0.1 0.1]);
bar(4:5,AvgMicBi(5:6),w2,'FaceColor',[1 0.1 0.1]);

legend([h1,h2],'Out','In','Location','northwest')



% Plot of A-weight
figure(35)
h1 = plot(1:31,-Aweight);
h1diagram = get(h1(1),'Parent');
set(h1diagram,'XTick',[3 6 9 12 15 18 21 24 27 30]);
set(h1diagram,'XTickLabel',labelvec)
set(h1diagram,'FontSize',14);
grid
g = xlabel('Frequency [Hz] 1/3 octave bands');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('A-weight');
set(g,'FontSize',14);
xlim([0 32])



figure(36)
%Widths for barplot
w1 = 0.8;
w2 = 0.6;
w3 = 0.4;
w4 = 0.2;
trainbar{1} = '4.90m';
trainbar{2} = '4.40m';
trainbar{3} = '3.60m';
trainbar{4} = '2.40m';
trainbar{5} = '1.75m';
h1 = bar(1:3,AvgMicSu(1:3),w1,'FaceColor',[0 0 1]);
h1diagram = get(h1(1),'Parent');
set(h1diagram,'XTick',[1 2 3 4 5]);
set(h1diagram,'XTickLabel',trainbar)
set(h1diagram,'FontSize',10);
grid
ylim([67 80])
g = xlabel('Microphone heights ');
set(g,'FontSize',14);
g = ylabel('Sound pressure level [dB]');
set(g,'FontSize',14);
g = title('Measured average for vehicles');
set(g,'FontSize',14);
hold on
bar(4:5,AvgMicSu(5:6),w1,'FaceColor',[0 0 1]);
h2 = bar(1:3,AvgMicSi(1:3),w2,'FaceColor',[1 0 0]);
bar(4:5,AvgMicSsi(5:6),w2,'FaceColor',[1 0 0]);
h3 = bar(1:3,AvgMicSsu(1:3),w3,'FaceColor',[0.3 0.3 0.8]);
bar(4:5,AvgMicSsu(5:6),w3,'FaceColor',[0.3 0.3 0.8]);
h4 = bar(1:3,AvgMicSsi(1:3),w4,'FaceColor',[0.8 0.3 0.3]);
bar(4:5,AvgMicSsi(5:6),w4,'FaceColor',[0.8 0.3 0.3]);
legend([h1,h2,h3,h4],'SL79 ut','SL79 inn','SL95 ut','SL95 inn','Location','northwest')
